@@ -102,14 +102,6 @@ def request_p0(url, user, password, xml_str=None, params=None):
         "content-type": 'text/xml; charset=utf-8',
     }
 
-    try:
-        client = Client(url, retxml=True, transport=t, cache=NoCache())
-    except urllib.error.URLError as e:
-        import ssl
-        ssl._create_default_https_context = ssl._create_unverified_context
-        client = Client(url, retxml=True, transport=t, cache=NoCache())
-    client.set_options(headers=auth_header)
-
     # Clean XML
     xml_str = xml_str.strip()
     xml_str = xml_str.replace("'utf-8'", "'UTF-8'")
@@ -120,8 +112,9 @@ def request_p0(url, user, password, xml_str=None, params=None):
     # principals que tenim. La "altres" i la "reintent"
     distri_envelop = ENVELOP_BY_DISTR.get(codi_receptor, ENVELOP_BY_DISTR.get("altres"))
     retry_envelop = ENVELOP_BY_DISTR.get("reintent")
+    retry2_envelop = ENVELOP_BY_DISTR.get("reintent_2")
     error = None
-    for envelop in [distri_envelop, retry_envelop]:
+    for envelop in [distri_envelop, retry_envelop, retry2_envelop]:
         xml_str_to_use = xml_str
         soap_content = envelop['template'].format(xml_str=xml_str_to_use)
 
@@ -157,13 +150,17 @@ def request_p0(url, user, password, xml_str=None, params=None):
             res = etree.tostring(aux_res)
             return res
         except P0FaultError as p0efe:
-            raise
+            if not error:
+                error = p0efe
         except Exception as e:
             if not error:
                 error = e
 
     if error:
-        print(error)
+        if isinstance(error, P0FaultError):
+            raise error
+        else:
+            print(error)
 
     return res
 
