@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-from message_gas import MessageGas
+from __future__ import absolute_import, unicode_literals
+from .message_gas import MessageGas
 from gestionatr.utils import get_rec_attr
 from gestionatr.defs_gas import TIPUS_CONCEPTES, PEAJES_SEMPRE_CAPACIDAD
 from datetime import datetime
@@ -1321,6 +1322,8 @@ class Medidor(object):
             dqmedio = float(meter.dqmedio)
             qdcontratado = float(meter.qdcontratado)
             excesocaudal = float(meter.excesocaudal)
+            temperatura_gas = float(meter.temp)
+            pressio_atmosferica = float(meter.presatm)
 
             for numerador in meter.listanumeradores:
                 lectura_desde_m3 = float(numerador.lectant)
@@ -1356,6 +1359,8 @@ class Medidor(object):
                     'dqmedio': float(dqmedio),
                     'qdcontratado': float(qdcontratado),
                     'excesocaudal': float(excesocaudal),
+                    'temperatura_gas': float(temperatura_gas),
+                    'pressio_atmosferica': float(pressio_atmosferica),
                 }
                 res.append(vals)
         return res
