@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-
-from C2 import C2, DatosSolicitud
-from Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
+from __future__ import absolute_import, unicode_literals
+from .C2 import C2, DatosSolicitud
+from .Deadlines import ProcessDeadline, DeadLine, Workdays, Naturaldays
 from gestionatr.utils import get_rec_attr
 
 
